#
# spec file for package nfdump
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define nfcapddatadir	%{_localstatedir}/lib/nfcapd
%define sfcapddatadir	%{_localstatedir}/lib/sfcapd
%define nfhomedir     %{_var}/lib/%{name}
Name:           nfdump
Version:        1.6.20
Release:        lp152.1.3
Summary:        CLI tools to collect and process netflow data
License:        BSD-3-Clause
Group:          Productivity/Networking/Diagnostic
URL:            https://github.com/phaag/nfdump
Source:         https://github.com/phaag/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  rrdtool
BuildRequires:  rrdtool-devel
BuildRequires:  pkgconfig(bzip2)
Requires:       rrdtool

%description
The nfdump tools collect and process netflow data on the command line.
They are part of the NFSEN project which is explained more detailed at
http://www.terena.nl/tech/task-forces/tf-csirt/meeting12/nfsen-Haag.pdf

%prep
%setup -q
chmod a-x AUTHORS COPYING LICENSE README.md ChangeLog

%build
autoreconf -fi
%configure \
	--enable-nfprofile \
	--enable-nftrack \
	--enable-nsel \
	--enable-sflow \
	--enable-shared=no
%make_build

%install
%make_install
install -D -d -m 0750 \
	%{buildroot}%{nfhomedir} \
	%{buildroot}%{nfcapddatadir} \
	%{buildroot}%{sfcapddatadir}
rm -f "%{buildroot}/%{_libdir}"/libnfdump.a
rm -f "%{buildroot}/%{_libdir}"/libnfdump.la

%pre
%{_sbindir}/groupadd -r %{name} &>/dev/null || :
%{_sbindir}/useradd -g %{name} -s /bin/false -r -c "User for Netflow Dumper" -d %{nfhomedir} %{name} &>/dev/null || :

%files
%license COPYING LICENSE
%doc AUTHORS README.md ChangeLog
%{_bindir}/nfanon
%{_bindir}/nfcapd
%{_bindir}/nfdump
%{_bindir}/nfexpire
%{_bindir}/nfprofile
%{_bindir}/nfreplay
%{_bindir}/nftrack
%{_bindir}/sfcapd
%{_mandir}/man1/ft2nfdump.1%{?ext_man}
%{_mandir}/man1/nfanon.1%{?ext_man}
%{_mandir}/man1/nfcapd.1%{?ext_man}
%{_mandir}/man1/nfdump.1%{?ext_man}
%{_mandir}/man1/nfexpire.1%{?ext_man}
%{_mandir}/man1/nfprofile.1%{?ext_man}
%{_mandir}/man1/nfreplay.1%{?ext_man}
%{_mandir}/man1/sfcapd.1%{?ext_man}
%dir %attr(-,%{name},%{name}) %{nfcapddatadir}
%dir %attr(-,%{name},%{name}) %{sfcapddatadir}
%dir %attr(-,%{name},%{name}) %{nfhomedir}

%changelog
* Sun Mar 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.6.20
  - More cleanup on plain number printing
  - Fix plain numbers bug #213
  - Fix profiler filer bug
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.6.19
  * This release is mainly a bug fix release and improves stability.
    Lot's of historical code cleanup - spring cleaning.
  * For a complete list of changes see the ChangeLog file:
    /usr/share/doc/packages/nfdump/ChangeLog
* Thu Aug  8 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.6.18
  * This release mainly Improves stability.
  * It adds nfpcapd to generate nfdump netflow records directly
    from interfaces/pcaps.
  * The old COMPAT15 mode has been removed. All old 1.5.x files
    should have been converted so far.
  * For a complete list of changes see the ChangeLog file:
    /usr/share/doc/packages/nfdump/ChangeLog
* Mon Apr 23 2018 mardnh@gmx.de
- Update to version 1.6.17
  * Fix bug in sorting when guessing flow direction.
  * Update nfdump.1 man page for xsrcport & xdstport aggregations.
  * Fix definition for InfluxDB in configure.ac
  * Add program exit in nfx.c after panic with correupt data file
  * Add missing size check when reading nfdump 1.5.x common record blocks
  * Add missing option -M in man page.
  * Add Fix processing of influx URL in nfprofile
  * Add missing json output format in nfdump help text
  * Add missing -v option in nfreplay help text
  * Merge pull request #51 Influxdb from Luca. Thx for the patch
  * IPFIX time stamps - Fix elements #21,#22 offset calculation, but
    timestamps not yet evaluated.
  * IPFIX add fwd status tag #89 compatible to v9 (1byte)
  * IPFIX sampling - sampling algorithm no longer required for tag #34
  * IPFIX sampling add tags #305 and #304 - set them identical to #34, #35
  * Add new output format json. Print each record as individual json object
  * Add sampling elements ID 302,304,305. put them identical to ID 48,49,50
  * Add option to label filter terms. syntax: (<filter>) %%labelname.
  * Add %%lbl option to print flow label in output
  * Update nfdump(1) man page for flowlabels
  * Add ipfix delta timestamp elements 158/159.
  * Update sflow code to commit 7322984 of https://github.com/sflow/sflowtool
  * Cleanup sflow code - uncomment unnecessary code
  * Fix header includes"
  * Fix 64bit fts compat issue in fts_compat.c
  * Add more detailed autogen.sh - softlink bootstrap
  * Fix potential memory leaks in nfpcapd
  * Fix wrong offset calculation if unknown options are found
  * Add x-late src/dst ip aggregation, if compiled with NSEL support
  * Add ipfix sampling. Process option template/record with sampling elements 34 and 35
  * Report updates on existing samplers in v9 only if values change. issue 84
* Sun Nov  5 2017 mardnh@gmx.de
- Fix URL
- Update to version 1.6.16
  * Add support for CISCO IOS 8 bytes timestamps ID 21/22
  * Fix issue #72 - multiple stat output
  * Change -B behaviour as proposed in issue #59.
    Should not impact with previous use, but is more flexible
  * Add bzip compress switch in usage output of nfpcapd
  * Fix compile issues on some platforms
  * nfpcapd improvements - still beta software.
  * Minor bug fixes
- Version 1.6.15
  * Fix Security issue
  * http://www.security-assessment.com/files/documents/advisory/Nfdump%%20nfcapd%%201.6.14%%20-%%20Multiple%%20Vulnerabilities.pdf
  * Fix obyte, opps and obps output records
  * Fix wrong bps type case in cvs output. Fix opbs ipbs typos
- Version 1.6.14
  * Create libnfdump for dynamic linking
  * Add -R to ModifyCompression
  * Add std sampler ID 4 Bytes and allow random sampler (tag 50)
  * Add BZ2 compression along existing LZ0
  * Add direct write to flowtools converter ft2nfdump
  * Fix CentOS compile issues with flow-tools converter
  * Fix FreeBSD,OpenBSD build problems
  * Fix timestamp overflow in sflow.c
  * Fix IP Fragmentation in sflow collector
  * Fix compile errors on other platforms
  * Fix zero alignment bug, if only half of an extension is sent
  * Fix nfanon time window bug in subsequent files in -R list
  * Fix CommonRecordV0Type conversion bug
  * Fix nfexport bug, if only one single map exists
* Mon Dec  1 2014 mardnh@gmx.de
- update to version 1.6.13
  * 2014-11-16 v1.6.13
  - Fix v1 extension size bug
  - Add htonll check for autoconf
  - Fix AddExtensionMap compare bug
  - Fix ipfix templare withdraw problems - free all maps correctly
  - Add minilzo 2.08 - fixes CVE-2014-4607
  - Cleanup some stat code. more needs to be done ..
  - Cleanup man pages for -O -n
  - Remove SunPro test in configure - no longer supported anyway
  - Cleanup NAT/NSEL filter differences
  * 2014-06-15 v1.6.12p1
  - Add pblock compare functions
  - Update extended filter: Allow modification left/right values
- removed duplicate files BSD-license.txt and NEWS
* Tue Jun 10 2014 mrueckert@suse.de
- initial package
